Index: src/mips/lithium-codegen-mips.cc |
diff --git a/src/mips/lithium-codegen-mips.cc b/src/mips/lithium-codegen-mips.cc |
index 58a8a61f0d81d9ba41247c0508fac906b2d9657a..2ee70ff45e3e42dbbdaf77f87e0ef6e8ae573003 100644 |
--- a/src/mips/lithium-codegen-mips.cc |
+++ b/src/mips/lithium-codegen-mips.cc |
@@ -159,9 +159,9 @@ bool LCodeGen::GeneratePrologue() { |
// The following three instructions must remain together and unmodified |
// for code aging to work properly. |
__ Push(ra, fp, cp, a1); |
// Add unused load of ip to ensure prologue sequence is identical for |
// full-codegen and lithium-codegen. |
- __ LoadRoot(at, Heap::kUndefinedValueRootIndex); |
+ __ nop(Assembler::CODE_AGE_SEQUENCE_NOP); |
// Adj. FP to point to saved FP. |
__ Addu(fp, sp, Operand(2 * kPointerSize)); |
} |
@@ -159,9 +159,9 @@ bool LCodeGen::GeneratePrologue() { |
// for code aging to work properly. |
__ Push(ra, fp, cp, a1); |
- // Add unused load of ip to ensure prologue sequence is identical for |
+ // Add unused nop to ensure prologue sequence is identical for |
// full-codegen and lithium-codegen. |